@@ -61,8 +61,8 @@
 #include <string.h>
 #include <stdio.h>
 
-#ifdef LINUX_INPUT
 #include <errno.h>
+#ifdef LINUX_INPUT
 #include <fcntl.h>
 #ifdef LINUX_SYSFS
 #include <sysfs/libsysfs.h>
@@ -70,6 +70,12 @@
 #endif
 #endif
 
+/* Previously found in xf86Xinput.h */
+#ifdef DBG
+#undef DBG
+#endif
+#define DBG(lvl, f) {if ((lvl) <= xf86GetVerbosity()) f;}
+
 /*****************************************************************************
  *	Local Headers
  ****************************************************************************/
@@ -185,7 +191,7 @@ IsUSBLine(int fd)
     }
 }
 
-/* Heavily inspired by synpatics/eventcomm.c */
+/* Heavily inspired by synaptics/eventcomm.c */
 
 #define DEV_INPUT_EVENT "/dev/input/event"
 #define EV_DEV_NAME_MAXLEN 64
@@ -196,8 +202,8 @@ static Bool
 fd_query_acecad(int fd, char *ace_name) {
     char name[256] = "Unknown";
     int cmp_at = strlen(ace_name);
-    if (cmp_at > 256)
-        cmp_at = 256;
+    if (cmp_at > 255)
+        cmp_at = 255;
     ioctl(fd, EVIOCGNAME(sizeof(name)), name);
     name[cmp_at] = '\0';
     if (xf86NameCmp(name, ace_name) == 0)
@@ -349,7 +355,9 @@ AceCadPreInit(InputDriverPtr drv, IDevPtr dev, int flags)
     local->name = dev->identifier;
     local->type_name = "ACECAD Tablet";
     local->flags = XI86_POINTER_CAPABLE | XI86_SEND_DRAG_EVENTS;
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) == 0
     local->motion_history_proc = xf86GetMotionEvents;
+#endif
     local->control_proc = NULL;
     local->close_proc = CloseProc;
     local->switch_mode = NULL;
@@ -488,8 +496,12 @@ SetupProc_fail:
         xf86CloseSerial (local->fd);
     if ((priv) && (priv->buffer))
         XisbFree (priv->buffer);
-    if (priv)
+    if (priv) {
         xfree (priv);
+	if (local)
+		local->private = NULL;
+    }
+    xf86DeleteInput(local, 0);
     return NULL;
 }
 
